/***********************************************************************/
/*                                                                     */
/*  FILE        :Main.c                                                */
/*  DATE        :25-Aug,2017                                          */
/*  DESCRIPTION :Main Program                                          */
/*  CPU TYPE    :RX24T                                                 */
/*                                                                     */
/*  NOTE:THIS IS A TYPICAL EXAMPLE.                                    */
/*                                                                     */
/***********************************************************************/

#ifdef  __ICCRX__
  #include <math.h>
  #include "r_cg_macrodriver.h"
  #include "r_cg_cgc.h"
  #include "r_cg_userdefine.h"
#elif   __CCRX__
  #include <machine.h>
  #include <mathf.h>
  #include <stdint.h>
  #include "iodefine.h"
//#include "r_cg_cgc.h"
#else
  //
#endif

#include "ICS2_RX24T.h"

void main(void);

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Set option bytes */

#ifdef   __ICCRX__

  #if __LITTLE_ENDIAN__
    #pragma public_equ="__MDES",0xFFFFFFFFUL
  #else
    #pragma public_equ="__MDES",0xFFFFFFF8UL
  #endif

  #pragma public_equ="__OFS0",0xFFFFFFFFUL
  #pragma public_equ="__OFS1",0xFFFFFFFFUL

#elif   __CCRX__  
  
  
#endif

#define  TWOPI    (2.0f*3.1415926535f)
                      //  BRR =   0         1      2      3     4
#define   BRR    0    // @80MHz 5.00Mbps, 2.50M, 1.67M, 1.25M, 1.00M
#define   MODE   3     // 0:16bit 8ch,one time
                       // 1:32bit 8ch,2 times
                       // 2:32bit 4ch,one time
                       // 3:32bit 12ch 3 times

#ifdef  __ICCRX__
  #pragma location=0x02000
  __no_init  uint32_t dtc_table[256]; /* alignment 0x000 */
#elif   __CCRX__
  #pragma address dtc_table=0x02000
  uint32_t dtc_table[256];            /* alignment 0x000 */
#endif

float   wt    = 0.0f;
float   dwt   = TWOPI*50.0f/10000.0f;
float   refu  = 0.0f;
float   refv  = 0.0f;
float   refw  = 0.0f;
float   m     = 1.0f;
float   dm    = 0.0001;
int32_t up    = 0;


void main(void)
{
#ifdef __CCRX__
    SYSTEM.PRCR.WORD = 0xA503;                 // disable resistor protection  

    SYSTEM.OPCCR.BIT.OPCM = 0;                 // switch to fast mode          
    while (SYSTEM.OPCCR.BIT.OPCMTSF != 0) { }  // wait until the mode is switched 

    SYSTEM.MOFCR.BYTE = 0x00;                  // main clock: 1 to 10MHz Xtal  
    SYSTEM.MOSCWTCR.BYTE = 0x04;               // clock wait time 2.048ms      
    SYSTEM.MOSCCR.BIT.MOSTP = 0;               // enable main clock oscillator 
    while (SYSTEM.OSCOVFSR.BIT.MOOVF == 0) { } // wait until main clock stabilized 

    SYSTEM.PLLCR.BIT.PLIDIV = 0;               // PLL͕  1
    SYSTEM.PLLCR.BIT.STC    = 0xF;             // PLL{ 10MHz x8  80MHz
    SYSTEM.PLLCR2.BIT.PLLEN = 0;               // enable PLL
    while (SYSTEM.OSCOVFSR.BIT.PLOVF == 0) { } // wait until PLL stabilized 

    do {
        SYSTEM.MEMWAIT.BIT.MEMWAIT = 2;        // enable memory wait
    }
    while (SYSTEM.MEMWAIT.BIT.MEMWAIT != 2);   // confirm the write value

    do {                                       //Max32MHz,  80MHz,   40MHz,   40MHz,   40MHz
        SYSTEM.SCKCR.LONG = 0x20010101;        // FCK:1/4,ICK:1/1,PCKA:1/1,PCKB:1/2,PCKD:1/2
    } while (SYSTEM.SCKCR.LONG != 0x20010101); // confirm the write value 
    SYSTEM.SCKCR3.WORD = 0x0400;               // select PLL 

    SYSTEM.PRCR.WORD = 0xA500; /* enable resistor protection */
#elif __ICCRX__
    
#endif

//**********************************************************************************
//                                                        //T5206 T6206 T6207 
//  ics2_init(dtc_table, ICS_SCI1_PD3_PD5, 6U, BRR, MODE); //CN2    CN8   CN3  if E1 is not used
    ics2_init(dtc_table, ICS_SCI5_PB5_PB6, 6U, BRR, MODE); //CN3    CN7   CN10 Default
//  ics2_init(dtc_table, ICS_SCI6_PB2_PB1, 6U, BRR, MODE); //CN4    CN6   CN9  
//  ics2_init(dtc_table, ICS_SCI6_PB0_PA5, 6U, BRR, MODE); // --     --   --   
//  ics2_init(dtc_table, ICS_SCI6_P81_P80, 6U, BRR, MODE); // --     --   CN1  
//  ics2_init(dtc_table, ICS_SCI6_P81_P80, 6U, BRR, MODE); // --     --   --   
//**********************************************************************************

#ifdef  __ICCRX__
    EI();
#elif   __CCRX__
    set_ipl(0); /* set lowest IPL level */
    setpsw_i();  // enable interrput
#else
    //
#endif
    
    while (1)
    {
        int32_t i;
        
        wt = wt + dwt;
        if (wt>TWOPI) { wt = wt - TWOPI; }
        
        if (up==1)
        {
             m = m + dm;
             if (m>=1.0f) { up = 0; }
        }
        else
        {
             m = m - dm;
             if (m<=0.5f) { up = 1; }
        }

        refu  = m * sinf(wt);
        refv  = m * sinf(wt-TWOPI*1.0f/3.0f);
        refw  = m * sinf(wt-TWOPI*2.0f/3.0f);

        for(i=0;i<2000;i++) { nop(); }

        ics2_watchpoint();
    }
}
